@@ -1,22 +1,19 @@
-/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
-
 /* gstreamermm - a C++ wrapper for gstreamer
  *
  * Copyright 2008 The gstreamermm Development Team
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 2
+ * as published by the Free Software Foundation.
  *
- * This library is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free
- * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
 #include <gtkmm/stock.h>
@@ -288,10 +285,10 @@ void PlayerWindow::on_button_open()
   {
     working_dir = chooser.get_current_folder();
 
-    // Set filename property on the file source. 
-    const std::string filename = chooser.get_filename(); //TODO: Can this use a URI?
-    m_source_element->property_location() = filename;
-    set_title( Glib::filename_display_basename(filename) );
+    // Set uri on the file source. 
+    const std::string uri = chooser.get_uri();
+    m_source_element->set_uri(uri);
+    set_title(uri);
 
     m_play_button.set_sensitive();
     display_label_progress(0, 0);
@@ -337,4 +334,3 @@ PlayerWindow::~PlayerWindow()
 {
   m_main_pipeline->get_bus()->remove_watch(m_watch_id);
 }
-
